@@ -89,7 +89,7 @@ query_cache_entry_free (gpointer data)
         QueryCacheEntry *entry = data;
 
 #ifdef QUERY_CACHE_DEBUG
-        g_warning ("Blowing item %p", entry);
+        g_message ("Blowing item %p", entry);
 #endif /* QUERY_CACHE_DEBUG */
 
         g_free (entry->query);
@@ -202,12 +202,12 @@ query_cache_lookup (const char   *query,
 	fake.sort_criteria = (char **) sort_criteria;
 	if ((entry = g_hash_table_lookup (query_cache, &fake))) {
 #ifdef QUERY_CACHE_DEBUG
-		g_warning ("\n\n ---  Hit (%p)  ---\n\n\n", entry->list);
+		g_message ("\n\n ---  Hit (%p)  ---\n\n\n", entry->list);
 #endif /* QUERY_CACHE_DEBUG */
 		result = Bonobo_ServerInfoList_duplicate (entry->list);
 	} else {
 #ifdef QUERY_CACHE_DEBUG
-		g_warning ("Miss");
+		g_message ("Miss");
 #endif /* QUERY_CACHE_DEBUG */
 		result = NULL;
 	}
@@ -240,7 +240,7 @@ query_cache_insert (const char   *query,
 	g_hash_table_replace (query_cache, entry, entry);
 
 #ifdef QUERY_CACHE_DEBUG
-	g_warning ("Query cache size now %d",
+	g_message ("Query cache size now %d",
                 g_hash_table_size (query_cache));
 #endif /* QUERY_CACHE_DEBUG */
 }
@@ -385,7 +385,7 @@ bonobo_activation_activate (const char             *requirements,
         if (ev->_major == CORBA_SYSTEM_EXCEPTION &&
             !strcmp (ev->_id, ex_CORBA_BAD_OPERATION)) /* fall-back */
         {
-                g_warning ("TESTME: Fall-back activate");
+                g_message ("TESTME: Fall-back activate");
                 result = Bonobo_ActivationContext_activateMatching
                         (ac, requirements, &selorder, &activation_environment,
                          flags, bonobo_activation_context_get (), ev);
@@ -744,26 +744,20 @@ bonobo_activation_init_activation_env (void)
 		const char *name;
 		const char *value;
 	} getenv_values[] = {
+#ifndef G_OS_WIN32
 		{ "DISPLAY",         NULL }, /* X display */
 		{ "SESSION_MANAGER", NULL }, /* XSMP session manager */
 		{ "AUDIODEV",        NULL }, /* Audio device on Sun systems */
-		{ "LANG",            NULL }, /* Fallback locale name */
                 { "XAUTHORITY",      NULL },
-		{ NULL,              NULL }
-	};
-
-	struct {
-		int         category;
-		const char *name;
-		const char *value;
-	} setlocale_values[] =  { /* locale information: see setlocale(3) */
-		{ LC_ALL,      "LC_ALL",          NULL },
-		{ LC_COLLATE,  "LC_COLLATE",      NULL }, 
-		{ LC_MESSAGES, "LC_MESSAGES",     NULL },
-		{ LC_MONETARY, "LC_MONETARY",     NULL },
-		{ LC_NUMERIC,  "LC_NUMERIC",      NULL },
-		{ LC_TIME,     "LC_TIME",         NULL },
-		{ 0,           NULL,              NULL }
+		{ "LC_ALL",	     NULL }, /* locale information: see setlocale(3) */
+		{ "LC_COLLATE",	     NULL }, 
+		{ "LC_MESSAGES",     NULL },
+		{ "LC_MONETARY",     NULL },
+		{ "LC_NUMERIC",	     NULL },
+		{ "LC_TIME",	     NULL },
+#endif
+		{ "LANG",            NULL }, /* Fallback locale name */
+		{ NULL,		     NULL }
 	};
 
 	for (i = 0; getenv_values [i].name; i++) {
@@ -773,19 +767,6 @@ bonobo_activation_init_activation_env (void)
 			num_items++;
 	}
 
-	for (i = 0; setlocale_values [i].name; i++) {
-		setlocale_values [i].value = setlocale (setlocale_values [i].category, NULL);
-
-		if (!setlocale_values [i].value)
-			setlocale_values [i].value = getenv (setlocale_values [i].name);
-
-		if (setlocale_values [i].value) {
-			num_items++;
-			if (setlocale_values [i].category == LC_ALL)
-				break; /* LC_ALL overrides all others */
-		}
-	}
-
 	if (!num_items)
 		return;
 
@@ -805,17 +786,6 @@ bonobo_activation_init_activation_env (void)
 			getenv_values [i].value);
 	}
 
-
-	for (i = 0; setlocale_values [i].name; i++) {
-		if (!setlocale_values [i].value)
-			continue;
-
-		Bonobo_ActivationEnvValue_set (
-			&activation_environment._buffer [j++],
-			setlocale_values [i].name,
-			setlocale_values [i].value);
-	}
-
 	g_assert (j == num_items);
 }
 
